@@ -11,7 +11,7 @@ Widgets for loop management
 
 # Category description for the widget registry
 
-NAME = "Loop Management"
+NAME = "Basic Loops"
 
 DESCRIPTION = "Widgets for Loop Management."
 
